@@ -584,15 +584,21 @@ Boolean labeltext(int keypressed, char *clientdata)
          int curloc, strpos;
          stringpart *strptr;
 
-         strptr = findstringpart(areawin->textpos - 1, &curloc, curlabel->string,
+         strpos = areawin->textpos - 1;
+         strptr = findstringpart(strpos, &curloc, curlabel->string,
 			 areawin->topinstance);
-         if ((curloc < 0) && (strptr != NULL) && (strptr->type == PARAM_END)) {
-	    undrawtext(curlabel);
-	    while (strptr->type != PARAM_START)
-	       strptr = findstringpart(--strpos, &curloc, curlabel->string,
+         if (curloc > 0) strpos -= curloc;	 /* move to beginning of string */
+         if ((strptr != NULL) && (strptr->type != PARAM_START) && (strpos > 0)) {
+            strpos--;
+	    strptr = findstringpart(strpos--, &curloc, curlabel->string,
 			areawin->topinstance);
-	    unmakeparam(curlabel, strptr);
-            do_redraw = True;
+	 }
+         if ((strptr != NULL) && (strptr->type == PARAM_START)) {
+            if (strpos >= 0) {
+	        undrawtext(curlabel);
+	        unmakeparam(curlabel, areawin->topinstance, strptr);
+                do_redraw = True;
+	    }
 	 }
       }
    }
